summaryrefslogtreecommitdiffstats
path: root/siplib/sipint.h
diff options
context:
space:
mode:
Diffstat (limited to 'siplib/sipint.h')
-rw-r--r--siplib/sipint.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/siplib/sipint.h b/siplib/sipint.h
index 19a8b1b..3758b36 100644
--- a/siplib/sipint.h
+++ b/siplib/sipint.h
@@ -89,9 +89,9 @@ PyObject *sip_api_convert_from_const_void_ptr_and_size(const void *val,
SIP_SSIZE_T size);
-extern sipQtAPI *sipQtSupport; /* The Qt support API. */
+extern sipTQtAPI *sipTQtSupport; /* The TQt support API. */
extern sipWrapperType sipSimpleWrapper_Type; /* The simple wrapper type. */
-extern sipTypeDef *sipQObjectType; /* The QObject type. */
+extern sipTypeDef *sipTQObjectType; /* The TQObject type. */
void *sipGetRx(sipSimpleWrapper *txSelf, const char *sigargs, PyObject *rxObj,
const char *slot, const char **memberp);